#
# spec file for package python-prometheus_client
#
# Copyright (c) 2017-2019 SUSE Software Solutions Germany GmbH
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python-prometheus-client
Version:        0.7.1
Release:        lp152.1.2
License:        Apache-2.0
Summary:        Python client for the Prometheus monitoring system
Url:            https://github.com/prometheus/client_python
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/p/prometheus_client/prometheus_client-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Suggests:       %{python_module twisted}
BuildArch:      noarch

%python_subpackages

%description
This library provides an API for exporting metrics from a Python application.
It provides classes for the metric types, and an HTTP server to expose the
metrics to Prometheus.

When using Linux, the process CPU, RAM, file descriptor usage and start time
will also be exported.

Along with the HTTP server to expose metrics, you can also write the metrics
to a text file to be exported by the prometheus-node-exporter, or push them to
the prometheus-pushgateway.

This library also includes support for re-exporting Graphite metrics to
Prometheus, custom collectors to proxy metrics for other systems and a parser
for the Prometheus text format.

%prep
%setup -q -n prometheus_client-%{version}

%build
%python_build

%install
%python_install

%files %{python_files}
%defattr(-,root,root,-)
%{python_sitelib}/*

%changelog
* Thu Nov 14 2019 Thomas Bechtold <tbechtold@suse.com>
  update to version v0.7.1
  * Fix lint related to operator positioning (#273)
  * Fix file descriptor not closed (#269)
  * Add basic openmetrics exposition
  * Add gsum/gcount to GaugeHistogram.
  * Fix multi process collision by initializing pid variable in master process (#192)
  * Use less genexprs in multiprocess accumulate
  * Refactor MetricWrapper magic to class hierarchy
  * Prevent double reading all values when collect multiprocess metrics (#262)
  * Fix lint around unused and star imports (#245)
  * Optimizations for tuples using. Removed unused types transformations. (#263)
  * Read only `used` bytes from MmapedDict files, not all the zeroes too
  * Check that quantile and le labels have Go %%g syntax, with .0 (#346)
  * Run isort
  * Avoid unpack_from() for a simple slice
  * Fix deadlock on gcCollector (#371)
  * Fix: #222. Support custom registry for MetricsHandler. (#223)
  * Enable flake8 import lint checking (#327)
  * Avoid duplicate JSON parsing and small allocations
  * correct spelling mistake (#193)
  * Fix unescaping (#291)
  * Add the GaugeHistogram
  * Remove unused time import (#200)
  * Disable GCCollector in multiprocess mode (#324)
  * Make WSGI metrics server not log requests (#203)
  * Add test for empty metadata, and the null byte.
  * helpful error message when multiprocessing dir env is unset (#206)
  * Add _created to Counter/Summary/Histogram
  * Add Info metric type.
  * Simplify code a bit
  * Add support for int values, UNIT, more tests.
  * Use `collections.defaultdict` to speed up metrics counting (#257)
  * Add UntypedMetricFamily to prometheus_client.core (#220)
  * Thread safety done right (#290)
  * Fix lint related to vertical whitespace (#246)
  * parser: ensure samples are of type Sample (#358)
  * Reduce unnecessary metric creation in loop (#256)
  * Remove duplicate code (#320)
  * Only test twisted on 3.7 (latest minor) (#428)
  * Fix thread leak in Python 3.7 #340 (#356)
  * b"Check exemplars are only where they're meant to be."
  * Add support for parsing timestamps
  * Fix #95: catch OSError when collecting file descriptors. (#205)
  * b"multiprocess: don't crash on missing gauge_live/sum files (#424)"
  * PEP333 does not require QUERY_STRING to be present. (#252)
  * Also set the mmap mode to match the read_mode flag.
  * Construct less tuples and dicts in accumulate
  * b"Avoid re-entrant calls to GC collector's callback (#343)"
  * Add python3.7 support (#418)
  * b"Check samples are grouped, untyped isn't used, and for invalid/missing le/quantile values."
  * b"Don't use mmap() when only reading a MmapedDict file"
  * Add OM timestamp support, and unittests
  * Fix lint for line continuation indents (#242)
  * Check for NaN counter values
  * Multiprocess mode: using direct assignment for writing into mmap (#315)
  * If only reading the mmap file, open in read-only mode.
  * Inirial work on OpenMetrics parser.
  * In multiprocess mode, ensure that metrics initialise to the correct (#328)
  * Example on how to expose metrics in a Flask application (#297)
  * Check for invalid info/stateset values.
  * Fix lint around operator spacing (#244)
  * Test and support Python 3.6 (#181)
  * py26 has fixed dependencies (#218)
  * Catch repeated metadata, and metadata after samples.
  * Added metrics to MetricFamily exceptions to fix #362 (#364)
  * Factor out value/timestamp/label parsing
  * Remove travis pypy version hack (#240)
  * optimize openmetrics text parsing (~4x perf) (#402)
  * Text parser optimization (~4.5x perf) (#282)
  * Check bucket rules are being followed
  * Permit subclassing of MetricsHandler (#339)
  * Document removal of _total from metric name.
  * Use precompiled struct methods for pack, unpack data (#266)
  * Add detailed Garbage Collection statistics. (#301)
  * Set default timeout of pushgateway actions to 30s (#237)
  * Fix bug in WSGI app code.
  * Add support for modelling and exposing exemplars
  * Add support for parsing exemplars
  * Add some more todos
  * Add tox env for running flake8 lint (#238)
  * Refactor everything out from `core.py` (but keep it for re-exports)
  * Update OM content type.
  * Check for negative counter-like, guage histogram, and quantile values. (#338)
  * Code style fixups (#325)
  * Disable gcCollector for pypy (#380)
  * Split MultiProcessCollector.__init__ for better profiling
  * Refactor MultiProcessCollector.collect() to allow for arbitrary merging. (#302)
  * read stat and limits files in binary mode (#234) (#235)
  * Ensure MetricFamily labels is a tuple (#184)
  * Fix SyntaxWarning due to unescaped sequence (#366)
  * Add support for Enum/StateSet
  * Change exemplar length limit to be only for label names+values (#397)
  * Fix small spelling error in README.md (#417)
  * Fix import of openmetrics, and make accept handling more general. (#318)
  * Add timestamp type for nano resolution
  * Check ordering within groups.
  * Check for non-real timestamps
  * Improve tests, handle trailing space after value.
  * Limit memory reads for mmaped files (#329)
  * Make indentation multiple of 4 spaces (#241)
  * Fix F811 redefinition lint (#239)
  * fstat mmap file only once
  * Expand unit support.
  * check Python version with sys.version_info (#227)
  * Fix issue #208: parse the correct scheme of URL in Python26 (#209)
  * Drop samples with duplicate timestamps, presumably due to truncation
  * compact MethodType between 2 and 3 (#403)
  * Make the format strings compatible with Python 2.6 (#361)
  * Check for exemplars being too long.
  * Switch to a namedtuple Sample for samples.
  * Make counter metric name not have _total internally.
  * flake8 compliance (#331)
  * flake8 test passing (#373)
  * Fix instrumentation link in README (#384)
  * Fix lint related to assigned but unused variables (#274)
  * multiprocess: pass None as default argument (#212)
  * Update CONTRIBUTING.md for DCO, test, and lint (#326)
  * OM changes untyped to unknown
- Drop python-devel BuildRequires. It's not needed
* Mon Jul 31 2017 vtheile@suse.com
  Initial package (0.0.20) for openSUSE.
